@@ -15,7 +15,10 @@ GQuark  bd_btrfs_error_quark (void) {
  * Creates a new copy of @info.
  */
 BDBtrfsDeviceInfo* bd_btrfs_device_info_copy (BDBtrfsDeviceInfo *info) {
-        BDBtrfsDeviceInfo *new_info = g_new0 (BDBtrfsDeviceInfo, 1);
+        if (info == NULL)
+        return NULL;
+
+    BDBtrfsDeviceInfo *new_info = g_new0 (BDBtrfsDeviceInfo, 1);
 
     new_info->id = info->id;
     new_info->path = g_strdup (info->path);
@@ -31,7 +34,10 @@ BDBtrfsDeviceInfo* bd_btrfs_device_info_copy (BDBtrfsDeviceInfo *info) {
  * Frees @info.
  */
 void  bd_btrfs_device_info_free (BDBtrfsDeviceInfo *info) {
-        g_free (info->path);
+        if (info == NULL)
+        return;
+
+    g_free (info->path);
     g_free (info);
 }
 
@@ -59,7 +65,10 @@ GType  bd_btrfs_device_info_get_type () {
  * Creates a new copy of @info.
  */
 BDBtrfsSubvolumeInfo* bd_btrfs_subvolume_info_copy (BDBtrfsSubvolumeInfo *info) {
-        BDBtrfsSubvolumeInfo *new_info = g_new0 (BDBtrfsSubvolumeInfo, 1);
+        if (info == NULL)
+        return NULL;
+
+    BDBtrfsSubvolumeInfo *new_info = g_new0 (BDBtrfsSubvolumeInfo, 1);
 
     new_info->id = info->id;
     new_info->parent_id = info->parent_id;
@@ -74,7 +83,10 @@ BDBtrfsSubvolumeInfo* bd_btrfs_subvolume_info_copy (BDBtrfsSubvolumeInfo *info)
  * Frees @info.
  */
 void  bd_btrfs_subvolume_info_free (BDBtrfsSubvolumeInfo *info) {
-        g_free (info->path);
+        if (info == NULL)
+        return;
+
+    g_free (info->path);
     g_free (info);
 }
 
@@ -103,7 +115,10 @@ GType  bd_btrfs_subvolume_info_get_type () {
  * Creates a new copy of @info.
  */
 BDBtrfsFilesystemInfo* bd_btrfs_filesystem_info_copy (BDBtrfsFilesystemInfo *info) {
-        BDBtrfsFilesystemInfo *new_info = g_new0 (BDBtrfsFilesystemInfo, 1);
+        if (info == NULL)
+        return NULL;
+
+    BDBtrfsFilesystemInfo *new_info = g_new0 (BDBtrfsFilesystemInfo, 1);
 
     new_info->label = g_strdup (info->label);
     new_info->uuid = g_strdup (info->uuid);
@@ -119,7 +134,10 @@ BDBtrfsFilesystemInfo* bd_btrfs_filesystem_info_copy (BDBtrfsFilesystemInfo *inf
  * Frees @info.
  */
 void  bd_btrfs_filesystem_info_free (BDBtrfsFilesystemInfo *info) {
-        g_free (info->label);
+        if (info == NULL)
+        return;
+
+    g_free (info->label);
     g_free (info->uuid);
     g_free (info);
 }
@@ -136,7 +154,7 @@ GType  bd_btrfs_filesystem_info_get_type () {
     return type;
 }
 
-static const gchar const * const btrfs_functions[] = {
+static const gchar* const btrfs_functions[] = {
     "bd_btrfs_is_tech_avail",
     "bd_btrfs_create_volume",
     "bd_btrfs_add_device",
@@ -156,7 +174,7 @@ static const gchar const * const btrfs_functions[] = {
     "bd_btrfs_change_label",
     NULL};
 
-gchar const * const * get_btrfs_functions (void) {
+const gchar* const* get_btrfs_functions (void) {
     return btrfs_functions;
 }
 
@@ -166,14 +184,14 @@ guint8 get_btrfs_num_functions (void) {
     return btrfs_num_functions;
 }
 
-gboolean  bd_btrfs_is_tech_avail_stub (BDBtrfsTech tech, guint64 mode, GError **error) {
+static gboolean  bd_btrfs_is_tech_avail_stub (BDBtrfsTech tech, guint64 mode, GError **error) {
     g_critical ("The function 'bd_btrfs_is_tech_avail' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_btrfs_is_tech_avail' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_btrfs_is_tech_avail) (BDBtrfsTech tech, guint64 mode, GError **error) = bd_btrfs_is_tech_avail_stub;
+static gboolean  (*_bd_btrfs_is_tech_avail) (BDBtrfsTech tech, guint64 mode, GError **error) = bd_btrfs_is_tech_avail_stub;
 
 /**
  * bd_btrfs_is_tech_avail:
@@ -189,14 +207,14 @@ gboolean  bd_btrfs_is_tech_avail (BDBtrfsTech tech, guint64 mode, GError **error
 }
 
 
-gboolean  bd_btrfs_create_volume_stub (const gchar **devices, const gchar *label, const gchar *data_level, const gchar *md_level, const BDExtraArg **extra, GError **error) {
+static gboolean  bd_btrfs_create_volume_stub (const gchar **devices, const gchar *label, const gchar *data_level, const gchar *md_level, const BDExtraArg **extra, GError **error) {
     g_critical ("The function 'bd_btrfs_create_volume' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_btrfs_create_volume' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_btrfs_create_volume) (const gchar **devices, const gchar *label, const gchar *data_level, const gchar *md_level, const BDExtraArg **extra, GError **error) = bd_btrfs_create_volume_stub;
+static gboolean  (*_bd_btrfs_create_volume) (const gchar **devices, const gchar *label, const gchar *data_level, const gchar *md_level, const BDExtraArg **extra, GError **error) = bd_btrfs_create_volume_stub;
 
 /**
  * bd_btrfs_create_volume:
@@ -219,14 +237,14 @@ gboolean  bd_btrfs_create_volume (const gchar **devices, const gchar *label, con
 }
 
 
-gboolean  bd_btrfs_add_device_stub (const gchar *mountpoint, const gchar *device, const BDExtraArg **extra, GError **error) {
+static gboolean  bd_btrfs_add_device_stub (const gchar *mountpoint, const gchar *device, const BDExtraArg **extra, GError **error) {
     g_critical ("The function 'bd_btrfs_add_device' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_btrfs_add_device' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_btrfs_add_device) (const gchar *mountpoint, const gchar *device, const BDExtraArg **extra, GError **error) = bd_btrfs_add_device_stub;
+static gboolean  (*_bd_btrfs_add_device) (const gchar *mountpoint, const gchar *device, const BDExtraArg **extra, GError **error) = bd_btrfs_add_device_stub;
 
 /**
  * bd_btrfs_add_device:
@@ -245,14 +263,14 @@ gboolean  bd_btrfs_add_device (const gchar *mountpoint, const gchar *device, con
 }
 
 
-gboolean  bd_btrfs_remove_device_stub (const gchar *mountpoint, const gchar *device, const BDExtraArg **extra, GError **error) {
+static gboolean  bd_btrfs_remove_device_stub (const gchar *mountpoint, const gchar *device, const BDExtraArg **extra, GError **error) {
     g_critical ("The function 'bd_btrfs_remove_device' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_btrfs_remove_device' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_btrfs_remove_device) (const gchar *mountpoint, const gchar *device, const BDExtraArg **extra, GError **error) = bd_btrfs_remove_device_stub;
+static gboolean  (*_bd_btrfs_remove_device) (const gchar *mountpoint, const gchar *device, const BDExtraArg **extra, GError **error) = bd_btrfs_remove_device_stub;
 
 /**
  * bd_btrfs_remove_device:
@@ -271,14 +289,14 @@ gboolean  bd_btrfs_remove_device (const gchar *mountpoint, const gchar *device,
 }
 
 
-gboolean  bd_btrfs_create_subvolume_stub (const gchar *mountpoint, const gchar *name, const BDExtraArg **extra, GError **error) {
+static gboolean  bd_btrfs_create_subvolume_stub (const gchar *mountpoint, const gchar *name, const BDExtraArg **extra, GError **error) {
     g_critical ("The function 'bd_btrfs_create_subvolume' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_btrfs_create_subvolume' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_btrfs_create_subvolume) (const gchar *mountpoint, const gchar *name, const BDExtraArg **extra, GError **error) = bd_btrfs_create_subvolume_stub;
+static gboolean  (*_bd_btrfs_create_subvolume) (const gchar *mountpoint, const gchar *name, const BDExtraArg **extra, GError **error) = bd_btrfs_create_subvolume_stub;
 
 /**
  * bd_btrfs_create_subvolume:
@@ -297,14 +315,14 @@ gboolean  bd_btrfs_create_subvolume (const gchar *mountpoint, const gchar *name,
 }
 
 
-gboolean  bd_btrfs_delete_subvolume_stub (const gchar *mountpoint, const gchar *name, const BDExtraArg **extra, GError **error) {
+static gboolean  bd_btrfs_delete_subvolume_stub (const gchar *mountpoint, const gchar *name, const BDExtraArg **extra, GError **error) {
     g_critical ("The function 'bd_btrfs_delete_subvolume' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_btrfs_delete_subvolume' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_btrfs_delete_subvolume) (const gchar *mountpoint, const gchar *name, const BDExtraArg **extra, GError **error) = bd_btrfs_delete_subvolume_stub;
+static gboolean  (*_bd_btrfs_delete_subvolume) (const gchar *mountpoint, const gchar *name, const BDExtraArg **extra, GError **error) = bd_btrfs_delete_subvolume_stub;
 
 /**
  * bd_btrfs_delete_subvolume:
@@ -323,14 +341,14 @@ gboolean  bd_btrfs_delete_subvolume (const gchar *mountpoint, const gchar *name,
 }
 
 
-guint64  bd_btrfs_get_default_subvolume_id_stub (const gchar *mountpoint, GError **error) {
+static guint64  bd_btrfs_get_default_subvolume_id_stub (const gchar *mountpoint, GError **error) {
     g_critical ("The function 'bd_btrfs_get_default_subvolume_id' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_btrfs_get_default_subvolume_id' called, but not implemented!");
     return 0;
 }
 
-guint64  (*_bd_btrfs_get_default_subvolume_id) (const gchar *mountpoint, GError **error) = bd_btrfs_get_default_subvolume_id_stub;
+static guint64  (*_bd_btrfs_get_default_subvolume_id) (const gchar *mountpoint, GError **error) = bd_btrfs_get_default_subvolume_id_stub;
 
 /**
  * bd_btrfs_get_default_subvolume_id:
@@ -347,14 +365,14 @@ guint64  bd_btrfs_get_default_subvolume_id (const gchar *mountpoint, GError **er
 }
 
 
-gboolean  bd_btrfs_set_default_subvolume_stub (const gchar *mountpoint, guint64 subvol_id, const BDExtraArg **extra, GError **error) {
+static gboolean  bd_btrfs_set_default_subvolume_stub (const gchar *mountpoint, guint64 subvol_id, const BDExtraArg **extra, GError **error) {
     g_critical ("The function 'bd_btrfs_set_default_subvolume' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_btrfs_set_default_subvolume' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_btrfs_set_default_subvolume) (const gchar *mountpoint, guint64 subvol_id, const BDExtraArg **extra, GError **error) = bd_btrfs_set_default_subvolume_stub;
+static gboolean  (*_bd_btrfs_set_default_subvolume) (const gchar *mountpoint, guint64 subvol_id, const BDExtraArg **extra, GError **error) = bd_btrfs_set_default_subvolume_stub;
 
 /**
  * bd_btrfs_set_default_subvolume:
@@ -374,14 +392,14 @@ gboolean  bd_btrfs_set_default_subvolume (const gchar *mountpoint, guint64 subvo
 }
 
 
-gboolean  bd_btrfs_create_snapshot_stub (const gchar *source, const gchar *dest, gboolean ro, const BDExtraArg **extra, GError **error) {
+static gboolean  bd_btrfs_create_snapshot_stub (const gchar *source, const gchar *dest, gboolean ro, const BDExtraArg **extra, GError **error) {
     g_critical ("The function 'bd_btrfs_create_snapshot' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_btrfs_create_snapshot' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_btrfs_create_snapshot) (const gchar *source, const gchar *dest, gboolean ro, const BDExtraArg **extra, GError **error) = bd_btrfs_create_snapshot_stub;
+static gboolean  (*_bd_btrfs_create_snapshot) (const gchar *source, const gchar *dest, gboolean ro, const BDExtraArg **extra, GError **error) = bd_btrfs_create_snapshot_stub;
 
 /**
  * bd_btrfs_create_snapshot:
@@ -401,14 +419,14 @@ gboolean  bd_btrfs_create_snapshot (const gchar *source, const gchar *dest, gboo
 }
 
 
-BDBtrfsDeviceInfo** bd_btrfs_list_devices_stub (const gchar *device, GError **error) {
+static BDBtrfsDeviceInfo** bd_btrfs_list_devices_stub (const gchar *device, GError **error) {
     g_critical ("The function 'bd_btrfs_list_devices' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_btrfs_list_devices' called, but not implemented!");
     return NULL;
 }
 
-BDBtrfsDeviceInfo** (*_bd_btrfs_list_devices) (const gchar *device, GError **error) = bd_btrfs_list_devices_stub;
+static BDBtrfsDeviceInfo** (*_bd_btrfs_list_devices) (const gchar *device, GError **error) = bd_btrfs_list_devices_stub;
 
 /**
  * bd_btrfs_list_devices:
@@ -425,14 +443,14 @@ BDBtrfsDeviceInfo** bd_btrfs_list_devices (const gchar *device, GError **error)
 }
 
 
-BDBtrfsSubvolumeInfo** bd_btrfs_list_subvolumes_stub (const gchar *mountpoint, gboolean snapshots_only, GError **error) {
+static BDBtrfsSubvolumeInfo** bd_btrfs_list_subvolumes_stub (const gchar *mountpoint, gboolean snapshots_only, GError **error) {
     g_critical ("The function 'bd_btrfs_list_subvolumes' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_btrfs_list_subvolumes' called, but not implemented!");
     return NULL;
 }
 
-BDBtrfsSubvolumeInfo** (*_bd_btrfs_list_subvolumes) (const gchar *mountpoint, gboolean snapshots_only, GError **error) = bd_btrfs_list_subvolumes_stub;
+static BDBtrfsSubvolumeInfo** (*_bd_btrfs_list_subvolumes) (const gchar *mountpoint, gboolean snapshots_only, GError **error) = bd_btrfs_list_subvolumes_stub;
 
 /**
  * bd_btrfs_list_subvolumes:
@@ -453,14 +471,14 @@ BDBtrfsSubvolumeInfo** bd_btrfs_list_subvolumes (const gchar *mountpoint, gboole
 }
 
 
-BDBtrfsFilesystemInfo* bd_btrfs_filesystem_info_stub (const gchar *device, GError **error) {
+static BDBtrfsFilesystemInfo* bd_btrfs_filesystem_info_stub (const gchar *device, GError **error) {
     g_critical ("The function 'bd_btrfs_filesystem_info' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_btrfs_filesystem_info' called, but not implemented!");
     return NULL;
 }
 
-BDBtrfsFilesystemInfo* (*_bd_btrfs_filesystem_info) (const gchar *device, GError **error) = bd_btrfs_filesystem_info_stub;
+static BDBtrfsFilesystemInfo* (*_bd_btrfs_filesystem_info) (const gchar *device, GError **error) = bd_btrfs_filesystem_info_stub;
 
 /**
  * bd_btrfs_filesystem_info:
@@ -476,14 +494,14 @@ BDBtrfsFilesystemInfo* bd_btrfs_filesystem_info (const gchar *device, GError **e
 }
 
 
-gboolean  bd_btrfs_mkfs_stub (const gchar **devices, const gchar *label, const gchar *data_level, const gchar *md_level, const BDExtraArg **extra, GError **error) {
+static gboolean  bd_btrfs_mkfs_stub (const gchar **devices, const gchar *label, const gchar *data_level, const gchar *md_level, const BDExtraArg **extra, GError **error) {
     g_critical ("The function 'bd_btrfs_mkfs' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_btrfs_mkfs' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_btrfs_mkfs) (const gchar **devices, const gchar *label, const gchar *data_level, const gchar *md_level, const BDExtraArg **extra, GError **error) = bd_btrfs_mkfs_stub;
+static gboolean  (*_bd_btrfs_mkfs) (const gchar **devices, const gchar *label, const gchar *data_level, const gchar *md_level, const BDExtraArg **extra, GError **error) = bd_btrfs_mkfs_stub;
 
 /**
  * bd_btrfs_mkfs:
@@ -506,14 +524,14 @@ gboolean  bd_btrfs_mkfs (const gchar **devices, const gchar *label, const gchar
 }
 
 
-gboolean  bd_btrfs_resize_stub (const gchar *mountpoint, guint64 size, const BDExtraArg **extra, GError **error) {
+static gboolean  bd_btrfs_resize_stub (const gchar *mountpoint, guint64 size, const BDExtraArg **extra, GError **error) {
     g_critical ("The function 'bd_btrfs_resize' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_btrfs_resize' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_btrfs_resize) (const gchar *mountpoint, guint64 size, const BDExtraArg **extra, GError **error) = bd_btrfs_resize_stub;
+static gboolean  (*_bd_btrfs_resize) (const gchar *mountpoint, guint64 size, const BDExtraArg **extra, GError **error) = bd_btrfs_resize_stub;
 
 /**
  * bd_btrfs_resize:
@@ -533,14 +551,14 @@ gboolean  bd_btrfs_resize (const gchar *mountpoint, guint64 size, const BDExtraA
 }
 
 
-gboolean  bd_btrfs_check_stub (const gchar *device, const BDExtraArg **extra, GError **error) {
+static gboolean  bd_btrfs_check_stub (const gchar *device, const BDExtraArg **extra, GError **error) {
     g_critical ("The function 'bd_btrfs_check' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_btrfs_check' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_btrfs_check) (const gchar *device, const BDExtraArg **extra, GError **error) = bd_btrfs_check_stub;
+static gboolean  (*_bd_btrfs_check) (const gchar *device, const BDExtraArg **extra, GError **error) = bd_btrfs_check_stub;
 
 /**
  * bd_btrfs_check:
@@ -558,14 +576,14 @@ gboolean  bd_btrfs_check (const gchar *device, const BDExtraArg **extra, GError
 }
 
 
-gboolean  bd_btrfs_repair_stub (const gchar *device, const BDExtraArg **extra, GError **error) {
+static gboolean  bd_btrfs_repair_stub (const gchar *device, const BDExtraArg **extra, GError **error) {
     g_critical ("The function 'bd_btrfs_repair' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_btrfs_repair' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_btrfs_repair) (const gchar *device, const BDExtraArg **extra, GError **error) = bd_btrfs_repair_stub;
+static gboolean  (*_bd_btrfs_repair) (const gchar *device, const BDExtraArg **extra, GError **error) = bd_btrfs_repair_stub;
 
 /**
  * bd_btrfs_repair:
@@ -583,14 +601,14 @@ gboolean  bd_btrfs_repair (const gchar *device, const BDExtraArg **extra, GError
 }
 
 
-gboolean  bd_btrfs_change_label_stub (const gchar *mountpoint, const gchar *label, const BDExtraArg **extra, GError **error) {
+static gboolean  bd_btrfs_change_label_stub (const gchar *mountpoint, const gchar *label, const BDExtraArg **extra, GError **error) {
     g_critical ("The function 'bd_btrfs_change_label' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_btrfs_change_label' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_btrfs_change_label) (const gchar *mountpoint, const gchar *label, const BDExtraArg **extra, GError **error) = bd_btrfs_change_label_stub;
+static gboolean  (*_bd_btrfs_change_label) (const gchar *mountpoint, const gchar *label, const BDExtraArg **extra, GError **error) = bd_btrfs_change_label_stub;
 
 /**
  * bd_btrfs_change_label:
