@@ -27,14 +27,14 @@ guint8 get_s390_num_functions (void) {
     return s390_num_functions;
 }
 
-gboolean  bd_s390_is_tech_avail_stub (BDS390Tech tech, guint64 mode, GError **error) {
+static gboolean  bd_s390_is_tech_avail_stub (BDS390Tech tech, guint64 mode, GError **error) {
     g_critical ("The function 'bd_s390_is_tech_avail' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_s390_is_tech_avail' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_s390_is_tech_avail) (BDS390Tech tech, guint64 mode, GError **error) = bd_s390_is_tech_avail_stub;
+static gboolean  (*_bd_s390_is_tech_avail) (BDS390Tech tech, guint64 mode, GError **error) = bd_s390_is_tech_avail_stub;
 
 /**
  * bd_s390_is_tech_avail:
@@ -50,14 +50,14 @@ gboolean  bd_s390_is_tech_avail (BDS390Tech tech, guint64 mode, GError **error)
 }
 
 
-gboolean  bd_s390_dasd_format_stub (const gchar *dasd, const BDExtraArg **extra, GError **error) {
+static gboolean  bd_s390_dasd_format_stub (const gchar *dasd, const BDExtraArg **extra, GError **error) {
     g_critical ("The function 'bd_s390_dasd_format' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_s390_dasd_format' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_s390_dasd_format) (const gchar *dasd, const BDExtraArg **extra, GError **error) = bd_s390_dasd_format_stub;
+static gboolean  (*_bd_s390_dasd_format) (const gchar *dasd, const BDExtraArg **extra, GError **error) = bd_s390_dasd_format_stub;
 
 /**
  * bd_s390_dasd_format:
@@ -75,14 +75,14 @@ gboolean  bd_s390_dasd_format (const gchar *dasd, const BDExtraArg **extra, GErr
 }
 
 
-gboolean  bd_s390_dasd_needs_format_stub (const gchar *dasd, GError **error) {
+static gboolean  bd_s390_dasd_needs_format_stub (const gchar *dasd, GError **error) {
     g_critical ("The function 'bd_s390_dasd_needs_format' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_s390_dasd_needs_format' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_s390_dasd_needs_format) (const gchar *dasd, GError **error) = bd_s390_dasd_needs_format_stub;
+static gboolean  (*_bd_s390_dasd_needs_format) (const gchar *dasd, GError **error) = bd_s390_dasd_needs_format_stub;
 
 /**
  * bd_s390_dasd_needs_format:
@@ -98,14 +98,14 @@ gboolean  bd_s390_dasd_needs_format (const gchar *dasd, GError **error) {
 }
 
 
-gboolean  bd_s390_dasd_online_stub (const gchar *dasd, GError **error) {
+static gboolean  bd_s390_dasd_online_stub (const gchar *dasd, GError **error) {
     g_critical ("The function 'bd_s390_dasd_online' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_s390_dasd_online' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_s390_dasd_online) (const gchar *dasd, GError **error) = bd_s390_dasd_online_stub;
+static gboolean  (*_bd_s390_dasd_online) (const gchar *dasd, GError **error) = bd_s390_dasd_online_stub;
 
 /**
  * bd_s390_dasd_online:
@@ -121,14 +121,14 @@ gboolean  bd_s390_dasd_online (const gchar *dasd, GError **error) {
 }
 
 
-gboolean  bd_s390_dasd_is_ldl_stub (const gchar *dasd, GError **error) {
+static gboolean  bd_s390_dasd_is_ldl_stub (const gchar *dasd, GError **error) {
     g_critical ("The function 'bd_s390_dasd_is_ldl' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_s390_dasd_is_ldl' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_s390_dasd_is_ldl) (const gchar *dasd, GError **error) = bd_s390_dasd_is_ldl_stub;
+static gboolean  (*_bd_s390_dasd_is_ldl) (const gchar *dasd, GError **error) = bd_s390_dasd_is_ldl_stub;
 
 /**
  * bd_s390_dasd_is_Ldl:
@@ -144,14 +144,14 @@ gboolean  bd_s390_dasd_is_ldl (const gchar *dasd, GError **error) {
 }
 
 
-gboolean  bd_s390_dasd_is_fba_stub (const gchar *dasd, GError **error) {
+static gboolean  bd_s390_dasd_is_fba_stub (const gchar *dasd, GError **error) {
     g_critical ("The function 'bd_s390_dasd_is_fba' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_s390_dasd_is_fba' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_s390_dasd_is_fba) (const gchar *dasd, GError **error) = bd_s390_dasd_is_fba_stub;
+static gboolean  (*_bd_s390_dasd_is_fba) (const gchar *dasd, GError **error) = bd_s390_dasd_is_fba_stub;
 
 /**
  * bd_s390_dasd_is_fba:
@@ -167,14 +167,14 @@ gboolean  bd_s390_dasd_is_fba (const gchar *dasd, GError **error) {
 }
 
 
-gchar* bd_s390_sanitize_dev_input_stub (const gchar *dev, GError **error) {
+static gchar* bd_s390_sanitize_dev_input_stub (const gchar *dev, GError **error) {
     g_critical ("The function 'bd_s390_sanitize_dev_input' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_s390_sanitize_dev_input' called, but not implemented!");
     return NULL;
 }
 
-gchar* (*_bd_s390_sanitize_dev_input) (const gchar *dev, GError **error) = bd_s390_sanitize_dev_input_stub;
+static gchar* (*_bd_s390_sanitize_dev_input) (const gchar *dev, GError **error) = bd_s390_sanitize_dev_input_stub;
 
 /**
  * bd_s390_sanitize_dev_input:
@@ -190,14 +190,14 @@ gchar* bd_s390_sanitize_dev_input (const gchar *dev, GError **error) {
 }
 
 
-gchar* bd_s390_zfcp_sanitize_wwpn_input_stub (const gchar *wwpn, GError **error) {
+static gchar* bd_s390_zfcp_sanitize_wwpn_input_stub (const gchar *wwpn, GError **error) {
     g_critical ("The function 'bd_s390_zfcp_sanitize_wwpn_input' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_s390_zfcp_sanitize_wwpn_input' called, but not implemented!");
     return NULL;
 }
 
-gchar* (*_bd_s390_zfcp_sanitize_wwpn_input) (const gchar *wwpn, GError **error) = bd_s390_zfcp_sanitize_wwpn_input_stub;
+static gchar* (*_bd_s390_zfcp_sanitize_wwpn_input) (const gchar *wwpn, GError **error) = bd_s390_zfcp_sanitize_wwpn_input_stub;
 
 /**
  * bd_s390_zfcp_sanitize_wwpn_input:
@@ -213,14 +213,14 @@ gchar* bd_s390_zfcp_sanitize_wwpn_input (const gchar *wwpn, GError **error) {
 }
 
 
-gchar* bd_s390_zfcp_sanitize_lun_input_stub (const gchar *lun, GError **error) {
+static gchar* bd_s390_zfcp_sanitize_lun_input_stub (const gchar *lun, GError **error) {
     g_critical ("The function 'bd_s390_zfcp_sanitize_lun_input' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_s390_zfcp_sanitize_lun_input' called, but not implemented!");
     return NULL;
 }
 
-gchar* (*_bd_s390_zfcp_sanitize_lun_input) (const gchar *lun, GError **error) = bd_s390_zfcp_sanitize_lun_input_stub;
+static gchar* (*_bd_s390_zfcp_sanitize_lun_input) (const gchar *lun, GError **error) = bd_s390_zfcp_sanitize_lun_input_stub;
 
 /**
  * bd_s390_zfcp_sanitize_lun_input:
@@ -236,14 +236,14 @@ gchar* bd_s390_zfcp_sanitize_lun_input (const gchar *lun, GError **error) {
 }
 
 
-gboolean  bd_s390_zfcp_online_stub (const gchar *devno, const gchar *wwpn, const gchar *lun, GError **error) {
+static gboolean  bd_s390_zfcp_online_stub (const gchar *devno, const gchar *wwpn, const gchar *lun, GError **error) {
     g_critical ("The function 'bd_s390_zfcp_online' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_s390_zfcp_online' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_s390_zfcp_online) (const gchar *devno, const gchar *wwpn, const gchar *lun, GError **error) = bd_s390_zfcp_online_stub;
+static gboolean  (*_bd_s390_zfcp_online) (const gchar *devno, const gchar *wwpn, const gchar *lun, GError **error) = bd_s390_zfcp_online_stub;
 
 /**
  * bd_s390_zfcp_online:
@@ -261,14 +261,14 @@ gboolean  bd_s390_zfcp_online (const gchar *devno, const gchar *wwpn, const gcha
 }
 
 
-gboolean  bd_s390_zfcp_scsi_offline_stub (const gchar *devno, const gchar *wwpn, const gchar *lun, GError **error) {
+static gboolean  bd_s390_zfcp_scsi_offline_stub (const gchar *devno, const gchar *wwpn, const gchar *lun, GError **error) {
     g_critical ("The function 'bd_s390_zfcp_scsi_offline' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_s390_zfcp_scsi_offline' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_s390_zfcp_scsi_offline) (const gchar *devno, const gchar *wwpn, const gchar *lun, GError **error) = bd_s390_zfcp_scsi_offline_stub;
+static gboolean  (*_bd_s390_zfcp_scsi_offline) (const gchar *devno, const gchar *wwpn, const gchar *lun, GError **error) = bd_s390_zfcp_scsi_offline_stub;
 
 /**
  * bd_s390_zfcp_scsi_offline:
@@ -294,14 +294,14 @@ gboolean  bd_s390_zfcp_scsi_offline (const gchar *devno, const gchar *wwpn, cons
 }
 
 
-gboolean  bd_s390_zfcp_offline_stub (const gchar *devno, const gchar *wwpn, const gchar *lun, GError **error) {
+static gboolean  bd_s390_zfcp_offline_stub (const gchar *devno, const gchar *wwpn, const gchar *lun, GError **error) {
     g_critical ("The function 'bd_s390_zfcp_offline' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_s390_zfcp_offline' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_s390_zfcp_offline) (const gchar *devno, const gchar *wwpn, const gchar *lun, GError **error) = bd_s390_zfcp_offline_stub;
+static gboolean  (*_bd_s390_zfcp_offline) (const gchar *devno, const gchar *wwpn, const gchar *lun, GError **error) = bd_s390_zfcp_offline_stub;
 
 /**
  * bd_s390_zfcp_offline:
