@@ -1,18 +1,18 @@
 /*
  * Copyright (C) 2014  Red Hat, Inc.
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, see <http://www.gnu.org/licenses/>.
  *
  * Author: Vratislav Podzimek <vpodzime@redhat.com>
  */
@@ -27,6 +27,7 @@
 #include <unistd.h>
 #include <errno.h>
 #include <syslog.h>
+#include <blkid.h>
 #include <blockdev/utils.h>
 
 #ifdef WITH_BD_ESCROW
@@ -66,28 +67,88 @@
  * Sizes are given in bytes unless stated otherwise.
  */
 
+BDCryptoLUKSPBKDF* bd_crypto_luks_pbkdf_copy (BDCryptoLUKSPBKDF *pbkdf) {
+    if (pbkdf == NULL)
+        return NULL;
+
+    BDCryptoLUKSPBKDF *new_pbkdf = g_new0 (BDCryptoLUKSPBKDF, 1);
+    new_pbkdf->type = g_strdup (pbkdf->type);
+    new_pbkdf->hash = g_strdup (pbkdf->hash);
+    new_pbkdf->max_memory_kb = pbkdf->max_memory_kb;
+    new_pbkdf->iterations = pbkdf->iterations;
+    new_pbkdf->time_ms = pbkdf->time_ms;
+    new_pbkdf->parallel_threads = pbkdf->parallel_threads;
+
+    return new_pbkdf;
+}
+
+void bd_crypto_luks_pbkdf_free (BDCryptoLUKSPBKDF *pbkdf) {
+    if (pbkdf == NULL)
+        return;
+
+    g_free (pbkdf->type);
+    g_free (pbkdf->hash);
+    g_free (pbkdf);
+}
+
+BDCryptoLUKSPBKDF* bd_crypto_luks_pbkdf_new (const gchar *type, const gchar *hash, guint32 max_memory_kb, guint32 iterations, guint32 time_ms, guint32 parallel_threads) {
+    BDCryptoLUKSPBKDF *ret = g_new0 (BDCryptoLUKSPBKDF, 1);
+    ret->type = g_strdup (type);
+    ret->hash = g_strdup (hash);
+    ret->max_memory_kb = max_memory_kb;
+    ret->iterations = iterations;
+    ret->time_ms = time_ms;
+    ret->parallel_threads = parallel_threads;
+
+    return ret;
+}
+
 BDCryptoLUKSExtra* bd_crypto_luks_extra_copy (BDCryptoLUKSExtra *extra) {
-   BDCryptoLUKSExtra *new_extra = g_new0 (BDCryptoLUKSExtra, 1);
+    if (extra == NULL)
+        return NULL;
 
-   new_extra->integrity = g_strdup (extra->integrity);
-   new_extra->data_alignment = extra->data_alignment;
-   new_extra->data_device = g_strdup (extra->data_device);
-   new_extra->sector_size = extra->sector_size;
-   new_extra->label = g_strdup (extra->label);
-   new_extra->subsystem = g_strdup (extra->subsystem);
+    BDCryptoLUKSExtra *new_extra = g_new0 (BDCryptoLUKSExtra, 1);
 
-   return new_extra;
+    new_extra->integrity = g_strdup (extra->integrity);
+    new_extra->data_alignment = extra->data_alignment;
+    new_extra->data_device = g_strdup (extra->data_device);
+    new_extra->sector_size = extra->sector_size;
+    new_extra->label = g_strdup (extra->label);
+    new_extra->subsystem = g_strdup (extra->subsystem);
+    new_extra->pbkdf = bd_crypto_luks_pbkdf_copy (extra->pbkdf);
+
+    return new_extra;
 }
 
 void bd_crypto_luks_extra_free (BDCryptoLUKSExtra *extra) {
-   g_free (extra->integrity);
-   g_free (extra->data_device);
-   g_free (extra->label);
-   g_free (extra->subsystem);
-   g_free (extra);
+    if (extra == NULL)
+        return;
+
+    g_free (extra->integrity);
+    g_free (extra->data_device);
+    g_free (extra->label);
+    g_free (extra->subsystem);
+    bd_crypto_luks_pbkdf_free (extra->pbkdf);
+    g_free (extra);
+}
+
+BDCryptoLUKSExtra* bd_crypto_luks_extra_new (guint64 data_alignment, const gchar *data_device, const gchar *integrity, guint64 sector_size, const gchar *label, const gchar *subsystem, BDCryptoLUKSPBKDF *pbkdf) {
+    BDCryptoLUKSExtra *ret = g_new0 (BDCryptoLUKSExtra, 1);
+    ret->integrity = g_strdup (integrity);
+    ret->data_alignment = data_alignment;
+    ret->data_device = g_strdup (data_device);
+    ret->sector_size = sector_size;
+    ret->label = g_strdup (label);
+    ret->subsystem = g_strdup (subsystem);
+    ret->pbkdf = bd_crypto_luks_pbkdf_copy (pbkdf);
+
+    return ret;
 }
 
 void bd_crypto_luks_info_free (BDCryptoLUKSInfo *info) {
+    if (info == NULL)
+        return;
+
     g_free (info->cipher);
     g_free (info->mode);
     g_free (info->uuid);
@@ -96,6 +157,9 @@ void bd_crypto_luks_info_free (BDCryptoLUKSInfo *info) {
 }
 
 BDCryptoLUKSInfo* bd_crypto_luks_info_copy (BDCryptoLUKSInfo *info) {
+    if (info == NULL)
+        return NULL;
+
     BDCryptoLUKSInfo *new_info = g_new0 (BDCryptoLUKSInfo, 1);
 
     new_info->version = info->version;
@@ -109,6 +173,9 @@ BDCryptoLUKSInfo* bd_crypto_luks_info_copy (BDCryptoLUKSInfo *info) {
 }
 
 void bd_crypto_integrity_info_free (BDCryptoIntegrityInfo *info) {
+    if (info == NULL)
+        return;
+
     g_free (info->algorithm);
     g_free (info->journal_crypt);
     g_free (info->journal_integrity);
@@ -116,6 +183,9 @@ void bd_crypto_integrity_info_free (BDCryptoIntegrityInfo *info) {
 }
 
 BDCryptoIntegrityInfo* bd_crypto_integrity_info_copy (BDCryptoIntegrityInfo *info) {
+    if (info == NULL)
+        return NULL;
+
     BDCryptoIntegrityInfo *new_info = g_new0 (BDCryptoIntegrityInfo, 1);
 
     new_info->algorithm = g_strdup (info->algorithm);
@@ -141,7 +211,7 @@ static locale_t c_locale = (locale_t) 0;
  * Function checking plugin's runtime dependencies.
  *
  */
-gboolean bd_crypto_check_deps () {
+gboolean bd_crypto_check_deps (void) {
     /* nothing to do here */
     return TRUE;
 }
@@ -179,7 +249,7 @@ static void crypto_log_redirect (gint level, const gchar *msg, void *usrptr __at
  * library's initialization functions.**
  *
  */
-gboolean bd_crypto_init () {
+gboolean bd_crypto_init (void) {
     c_locale = newlocale (LC_ALL_MASK, "C", c_locale);
     crypt_set_log_callback (NULL, &crypto_log_redirect, NULL);
     return TRUE;
@@ -192,7 +262,7 @@ gboolean bd_crypto_init () {
  * library's functions that unload it.**
  *
  */
-void bd_crypto_close () {
+void bd_crypto_close (void) {
     c_locale = (locale_t) 0;
     crypt_set_log_callback (NULL, NULL, NULL);
 }
@@ -326,19 +396,103 @@ gchar* bd_crypto_generate_backup_passphrase(GError **error __attribute__((unused
  * Tech category: %BD_CRYPTO_TECH_LUKS-%BD_CRYPTO_TECH_MODE_QUERY
  */
 gboolean bd_crypto_device_is_luks (const gchar *device, GError **error) {
-    struct crypt_device *cd = NULL;
-    gint ret;
+    blkid_probe probe = NULL;
+    gint fd = 0;
+    gint status = 0;
+    const gchar *value = NULL;
+    guint n_try = 0;
 
-    ret = crypt_init (&cd, device);
-    if (ret != 0) {
+    probe = blkid_new_probe ();
+    if (!probe) {
         g_set_error (error, BD_CRYPTO_ERROR, BD_CRYPTO_ERROR_DEVICE,
-                     "Failed to initialize device: %s", strerror_l(-ret, c_locale));
+                     "Failed to create a new probe");
         return FALSE;
     }
 
-    ret = crypt_load (cd, CRYPT_LUKS, NULL);
-    crypt_free (cd);
-    return (ret == 0);
+    fd = open (device, O_RDONLY|O_CLOEXEC);
+    if (fd == -1) {
+        g_set_error (error, BD_CRYPTO_ERROR, BD_CRYPTO_ERROR_DEVICE,
+                     "Failed to open the device '%s'", device);
+        blkid_free_probe (probe);
+        return FALSE;
+    }
+
+    /* we may need to try mutliple times with some delays in case the device is
+       busy at the very moment */
+    for (n_try=5, status=-1; (status != 0) && (n_try > 0); n_try--) {
+        status = blkid_probe_set_device (probe, fd, 0, 0);
+        if (status != 0)
+            g_usleep (100 * 1000); /* microseconds */
+    }
+    if (status != 0) {
+        g_set_error (error, BD_CRYPTO_ERROR, BD_CRYPTO_ERROR_DEVICE,
+                     "Failed to create a probe for the device '%s'", device);
+        blkid_free_probe (probe);
+        close (fd);
+        return FALSE;
+    }
+
+    blkid_probe_enable_partitions (probe, 1);
+    blkid_probe_set_partitions_flags (probe, BLKID_PARTS_MAGIC);
+    blkid_probe_enable_superblocks (probe, 1);
+    blkid_probe_set_superblocks_flags (probe, BLKID_SUBLKS_USAGE | BLKID_SUBLKS_TYPE |
+                                              BLKID_SUBLKS_MAGIC | BLKID_SUBLKS_BADCSUM);
+
+    /* we may need to try mutliple times with some delays in case the device is
+       busy at the very moment */
+    for (n_try=5, status=-1; !(status == 0 || status == 1) && (n_try > 0); n_try--) {
+        status = blkid_do_safeprobe (probe);
+        if (status < 0)
+            g_usleep (100 * 1000); /* microseconds */
+    }
+    if (status < 0) {
+        /* -1 or -2 = error during probing*/
+        g_set_error (error, BD_CRYPTO_ERROR, BD_CRYPTO_ERROR_DEVICE,
+                     "Failed to probe the device '%s'", device);
+        blkid_free_probe (probe);
+        close (fd);
+        return FALSE;
+    } else if (status == 1) {
+        /* 1 = nothing detected */
+        blkid_free_probe (probe);
+        close (fd);
+        return FALSE;
+    }
+
+    status = blkid_probe_lookup_value (probe, "USAGE", &value, NULL);
+    if (status != 0) {
+        g_set_error (error, BD_CRYPTO_ERROR, BD_CRYPTO_ERROR_DEVICE,
+                     "Failed to get usage for the device '%s'", device);
+        blkid_free_probe (probe);
+        close (fd);
+        return FALSE;
+    }
+
+    if (g_strcmp0 (value, "crypto") != 0) {
+        blkid_free_probe (probe);
+        close (fd);
+        return FALSE;
+    }
+
+    status = blkid_probe_lookup_value (probe, "TYPE", &value, NULL);
+    if (status != 0) {
+        g_set_error (error, BD_CRYPTO_ERROR, BD_CRYPTO_ERROR_DEVICE,
+                     "Failed to get filesystem type for the device '%s'", device);
+        blkid_free_probe (probe);
+        close (fd);
+        return FALSE;
+    }
+
+    if (g_strcmp0 (value, "crypto_LUKS") != 0) {
+        blkid_free_probe (probe);
+        close (fd);
+        return FALSE;
+    }
+
+    blkid_free_probe (probe);
+    close (fd);
+
+    return TRUE;
 }
 
 /**
@@ -428,7 +582,7 @@ guint64 bd_crypto_luks_get_metadata_size (const gchar *device, GError **error) {
 gchar* bd_crypto_luks_status (const gchar *luks_device, GError **error) {
     struct crypt_device *cd = NULL;
     gint ret_num;
-    gchar *ret = NULL;
+    const gchar *ret = NULL;
     crypt_status_info status;
 
     ret_num = crypt_init_by_name (&cd, luks_device);
@@ -459,9 +613,83 @@ gchar* bd_crypto_luks_status (const gchar *luks_device, GError **error) {
     }
 
     crypt_free (cd);
-    return ret;
+    /* cast the "const" away because this API requires returning a
+       non-const string, though the caller isn't allowed to modify its
+       contents */
+    return (gchar *)ret;
 }
 
+#ifdef LIBCRYPTSETUP_2
+static struct crypt_pbkdf_type *get_pbkdf_params (BDCryptoLUKSPBKDF *user_pbkdf, GError **error) {
+    const struct crypt_pbkdf_type *default_pbkdf = NULL;
+    struct crypt_pbkdf_type *new_pbkdf = NULL;
+
+    if (user_pbkdf == NULL)
+        return NULL;
+
+    /* crypt_get_pbkdf_default returns default pbkdf parameters only based
+       on the luks version -- so for LUKS2 it returns default values for
+       argon2 but we also need to be able to provide default values if user
+       wants pbkdf2 and only specifies type -- we will use the defaults for
+       argon2 and ignore parameters specific to it
+       better API for this should be part of cryptsetup 2.0.4
+     */
+    default_pbkdf = crypt_get_pbkdf_default (CRYPT_LUKS2);
+    if (!default_pbkdf) {
+        g_set_error (error, BD_CRYPTO_ERROR, BD_CRYPTO_ERROR_FORMAT_FAILED,
+                     "Failed to get default values for pbkdf.");
+        return NULL;
+    }
+
+    new_pbkdf = g_new0 (struct crypt_pbkdf_type, 1);
+
+    new_pbkdf->flags = default_pbkdf->flags;
+
+    if (user_pbkdf->type)
+        new_pbkdf->type = user_pbkdf->type;
+    else
+        new_pbkdf->type = default_pbkdf->type;
+
+    if (user_pbkdf->hash)
+        new_pbkdf->hash = user_pbkdf->hash;
+    else
+        new_pbkdf->hash = default_pbkdf->hash;
+
+    if (user_pbkdf->time_ms)
+        new_pbkdf->time_ms = user_pbkdf->time_ms;
+    else
+        new_pbkdf->time_ms = default_pbkdf->time_ms;
+
+    if (user_pbkdf->iterations) {
+        new_pbkdf->iterations = user_pbkdf->iterations;
+        /* iterations set manually -> do not run benchmark */
+        new_pbkdf->flags = CRYPT_PBKDF_NO_BENCHMARK;
+    } else
+        new_pbkdf->iterations = default_pbkdf->iterations;
+
+    /* 'max_memory_kb' and 'parallel_threads' are not used in pbkdf2 */
+    if (g_strcmp0 (user_pbkdf->type, CRYPT_KDF_PBKDF2) == 0) {
+        if (user_pbkdf->max_memory_kb)
+            bd_utils_log (LOG_WARNING, "'max_memory_kb' is not valid option for 'pbkdf2', ignoring.");
+
+        new_pbkdf->max_memory_kb = 0;
+        new_pbkdf->parallel_threads = 0;
+    } else {
+        if (user_pbkdf->max_memory_kb)
+            new_pbkdf->max_memory_kb = user_pbkdf->max_memory_kb;
+        else
+            new_pbkdf->max_memory_kb = default_pbkdf->max_memory_kb;
+
+        if (user_pbkdf->parallel_threads)
+            new_pbkdf->parallel_threads = user_pbkdf->parallel_threads;
+        else
+            new_pbkdf->parallel_threads = default_pbkdf->parallel_threads;
+    }
+
+    return new_pbkdf;
+}
+#endif
+
 static gboolean luks_format (const gchar *device, const gchar *cipher, guint64 key_size, const guint8 *pass_data, gsize data_size, const gchar *key_file, guint64 min_entropy, BDCryptoLUKSVersion luks_version, BDCryptoLUKSExtra *extra, GError **error) {
     struct crypt_device *cd = NULL;
     gint ret;
@@ -545,7 +773,7 @@ static gboolean luks_format (const gchar *device, const gchar *cipher, guint64 k
     if (extra) {
         if (luks_version == BD_CRYPTO_LUKS_VERSION_LUKS1) {
 
-            if (extra->integrity || extra->sector_size || extra->label || extra->subsystem) {
+            if (extra->integrity || extra->sector_size || extra->label || extra->subsystem || extra->pbkdf) {
                 g_set_error (error, BD_CRYPTO_ERROR, BD_CRYPTO_ERROR_INVALID_PARAMS,
                              "Invalid extra arguments specified. Only `data_alignment`"
                              "and `data_device` are valid for LUKS 1.");
@@ -563,8 +791,20 @@ static gboolean luks_format (const gchar *device, const gchar *cipher, guint64 k
         }
 #ifdef LIBCRYPTSETUP_2
         else if (luks_version == BD_CRYPTO_LUKS_VERSION_LUKS2) {
+            GError *loc_error = NULL;
             struct crypt_params_luks2 params = ZERO_INIT;
-            params.pbkdf = NULL;
+            struct crypt_pbkdf_type *pbkdf = get_pbkdf_params (extra->pbkdf, &loc_error);
+
+            if (pbkdf == NULL && loc_error != NULL) {
+                crypt_free (cd);
+                g_strfreev (cipher_specs);
+                bd_utils_report_finished (progress_id, loc_error->message);
+                g_propagate_prefixed_error (error, loc_error,
+                                            "Failed to get PBKDF parameters for '%s'.", device);
+                return FALSE;
+            }
+
+            params.pbkdf = pbkdf;
             params.integrity = extra->integrity;
             params.integrity_params = NULL;
             params.data_alignment = extra->data_alignment;
@@ -574,6 +814,7 @@ static gboolean luks_format (const gchar *device, const gchar *cipher, guint64 k
             params.subsystem = extra->subsystem;
             ret = crypt_format (cd, crypt_version, cipher_specs[0], cipher_specs[1],
                                 NULL, NULL, key_size, &params);
+            g_free (pbkdf);
         }
 #endif
     } else
@@ -1851,9 +2092,8 @@ gboolean bd_crypto_tc_open_full (const gchar *device, const gchar *name, const g
     g_free (msg);
 
     if (keyfiles) {
-        for (i=0; *(keyfiles + i); i++) {
-            keyfiles_count = i;
-        }
+        for (i=0; *(keyfiles + i); i++);
+        keyfiles_count = i;
     }
 
     if ((data_len == 0) && (keyfiles_count == 0)) {
