@@ -1,18 +1,18 @@
 /*
  * Copyright (C) 2014-2017 Red Hat, Inc.
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, see <http://www.gnu.org/licenses/>.
  *
  * Author: Vratislav Podzimek <vpodzime@redhat.com>
  */
@@ -53,7 +53,7 @@ static GMutex deps_check_lock;
 #define DEPS_SWAPLABEL_MASK (1 << DEPS_SWAPLABEL)
 #define DEPS_LAST 2
 
-static UtilDep deps[DEPS_LAST] = {
+static const UtilDep deps[DEPS_LAST] = {
     {"mkswap", MKSWAP_MIN_VERSION, NULL, "mkswap from util-linux ([\\d\\.]+)"},
     {"swaplabel", NULL, NULL, NULL},
 };
@@ -67,7 +67,7 @@ static UtilDep deps[DEPS_LAST] = {
  * Function checking plugin's runtime dependencies.
  *
  */
-gboolean bd_swap_check_deps () {
+gboolean bd_swap_check_deps (void) {
     GError *error = NULL;
     guint i = 0;
     gboolean status = FALSE;
@@ -97,7 +97,7 @@ gboolean bd_swap_check_deps () {
  * library's initialization functions.**
  *
  */
-gboolean bd_swap_init () {
+gboolean bd_swap_init (void) {
     /* nothing to do here */
     return TRUE;
 };
@@ -109,7 +109,7 @@ gboolean bd_swap_init () {
  * library's functions that unload it.**
  *
  */
-void bd_swap_close () {
+void bd_swap_close (void) {
     /* nothing to do here */
 }
 
