@@ -5,7 +5,7 @@ import subprocess
 import tempfile
 from contextlib import contextmanager
 import utils
-from utils import run, create_sparse_tempfile, mount, umount, unstable_test
+from utils import run, create_sparse_tempfile, mount, umount, unstable_test, skip_on
 import six
 import overrides_hack
 
@@ -24,8 +24,8 @@ def check_output(args, ignore_retcode=True):
             raise
 
 @contextmanager
-def mounted(device, where):
-    mount(device, where)
+def mounted(device, where, ro=False):
+    mount(device, where, ro)
     yield
     umount(where)
 
@@ -86,6 +86,16 @@ class FSTestCase(unittest.TestCase):
         except:
             pass
 
+    def setro(self, device):
+        ret, _out, _err = utils.run_command("blockdev --setro %s" % device)
+        if ret != 0:
+            self.fail("Failed to set %s read-only" % device)
+
+    def setrw(self, device):
+        ret, _out, _err = utils.run_command("blockdev --setrw %s" % device)
+        if ret != 0:
+            self.fail("Failed to set %s read-write" % device)
+
 class TestGenericWipe(FSTestCase):
     def test_generic_wipe(self):
         """Verify that generic signature wipe works as expected"""
@@ -560,9 +570,9 @@ class XfsTestCheck(FSTestCase):
         succ = BlockDev.fs_xfs_check(self.loop_dev)
         self.assertTrue(succ)
 
-        # mounted, but can be checked and nothing happened in/to the file
-        # system, so it should be just reported as clean
-        with mounted(self.loop_dev, self.mount_dir):
+        # mounted RO, can be checked and nothing happened in/to the file system,
+        # so it should be just reported as clean
+        with mounted(self.loop_dev, self.mount_dir, ro=True):
             succ = BlockDev.fs_xfs_check(self.loop_dev)
             self.assertTrue(succ)
 
@@ -1125,6 +1135,68 @@ class MountTest(FSTestCase):
             BlockDev.fs_unmount(self.loop_dev, run_as_uid=uid, run_as_gid=gid)
         self.assertTrue(os.path.ismount(tmp))
 
+    @skip_on("debian", "testing", reason="NTFS mounting is broken on Debian testing")
+    def test_mount_ntfs(self):
+        """ Test basic mounting and unmounting with NTFS filesystem"""
+        # using NTFS because it uses a helper program (mount.ntfs) and libmount
+        # behaves differently because of that
+
+        if not self.ntfs_avail:
+            self.skipTest("skipping NTFS: not available")
+
+        succ = BlockDev.fs_ntfs_mkfs(self.loop_dev, None)
+        self.assertTrue(succ)
+
+        tmp = tempfile.mkdtemp(prefix="libblockdev.", suffix="mount_test")
+        self.addCleanup(os.rmdir, tmp)
+
+        self.addCleanup(umount, self.loop_dev)
+
+        succ = BlockDev.fs_mount(self.loop_dev, tmp, "ntfs", None)
+        self.assertTrue(succ)
+        self.assertTrue(os.path.ismount(tmp))
+
+        succ = BlockDev.fs_unmount(self.loop_dev, False, False, None)
+        self.assertTrue(succ)
+        self.assertFalse(os.path.ismount(tmp))
+
+        mnt = BlockDev.fs_get_mountpoint(self.loop_dev)
+        self.assertIsNone(mnt)
+
+        # mount again to test unmount using the mountpoint
+        succ = BlockDev.fs_mount(self.loop_dev, tmp, None, None)
+        self.assertTrue(succ)
+        self.assertTrue(os.path.ismount(tmp))
+
+        succ = BlockDev.fs_unmount(tmp, False, False, None)
+        self.assertTrue(succ)
+        self.assertFalse(os.path.ismount(tmp))
+
+        # mount with some options
+        succ = BlockDev.fs_mount(self.loop_dev, tmp, "ntfs", "ro")
+        self.assertTrue(succ)
+        self.assertTrue(os.path.ismount(tmp))
+        _ret, out, _err = utils.run_command("grep %s /proc/mounts" % tmp)
+        self.assertTrue(out)
+        self.assertIn("ro", out)
+
+        succ = BlockDev.fs_unmount(self.loop_dev, False, False, None)
+        self.assertTrue(succ)
+        self.assertFalse(os.path.ismount(tmp))
+
+        # set the device read-only
+        self.setro(self.loop_dev)
+        self.addCleanup(self.setrw, self.loop_dev)
+
+        # standard mount (rw) should fail
+        with self.assertRaises(GLib.GError):
+            BlockDev.fs_mount(self.loop_dev, tmp, "ntfs", None)
+
+        # read-only mount should work
+        succ = BlockDev.fs_mount(self.loop_dev, tmp, "ntfs", "ro")
+        self.assertTrue(succ)
+        self.assertTrue(os.path.ismount(tmp))
+
 class GenericCheck(FSTestCase):
     log = []
 
